package com.nationrel.modules.pdsc.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;
import lombok.experimental.Accessors;
import org.jeecg.common.aspect.annotation.Dict;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * @Description: project_info
 * @Author: nationrel
 * @Date: 2024-05-22
 * @Version: V1.0
 */
@Builder
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
@TableName(value = "project_info", autoResultMap = true)
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@Schema(description = "project_info")
public class ProjectInfo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @TableId(type = IdType.ASSIGN_ID)
    @Schema(description = "主键")
    private String id;
    /**
     * PDSC编号
     */
    @Excel(name = "PDSC编号", width = 15)
    @Schema(description = "PDSC编号")
    private String code;
    /**
     * PDSC名称
     */
    @Excel(name = "PDSC名称", width = 15)
    @Schema(description = "PDSC名称")
    private String name;
    /**
     * 项目名称
     */
    @Excel(name = "项目名称", width = 15)
    @Schema(description = "项目名称")
    private String projectName;
    /**
     * 产品名称
     */
    @Excel(name = "产品名称", width = 15)
    @Schema(description = "产品名称")
    private String productName;
    /**
     * 项目类型
     */
    @Excel(name = "项目类型", width = 15)
    @Schema(description = "项目类型")
    @Dict(dicCode = "nationrel_pdsc_project_type")
    private String projectType;
    /**
     * 项目阶段
     */
    @Excel(name = "项目阶段", width = 15)
    @Schema(description = "项目阶段")
    private String projectStage;
    /**
     * CTQ等级
     */
    @Excel(name = "CTQ等级", width = 15)
    @Schema(description = "CTQ等级")
    @Dict(dicCode = "nationrel_pdsc_ctq_grade")
    private String ctqGrade;
    /**
     * Owner
     */
    @Excel(name = "Owner", width = 15)
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "id")
    @Schema(description = "Owner")
    private String owner;
    /**
     * 状态
     */
    @Excel(name = "状态", width = 15)
    @Dict(dicCode = "nationrel_pdsc_status")
    @Schema(description = "状态")
    private String status;
    /**
     * 版本
     */
    @Excel(name = "版本", width = 15)
    @Schema(description = "版本")
    private Integer version;
    /**
     * 下一版本
     */
    @Excel(name = "下一版本", width = 15)
    @Schema(description = "下一版本")
    private Integer nextVersion;
    /**
     * 第零关卡时间
     */
    @Excel(name = "第零关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第零关卡时间")
    private Date zeroLevelTime;
    /**
     * 第一关卡时间
     */
    @Excel(name = "第一关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第一关卡时间")
    private Date oneLevelTime;
    /**
     * 第二关卡时间
     */
    @Excel(name = "第二关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第二关卡时间")
    private Date twoLevelTime;
    /**
     * 第三关卡时间
     */
    @Excel(name = "第三关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第三关卡时间")
    private Date threeLevelTime;
    /**
     * 第四关卡时间
     */
    @Excel(name = "第四关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第四关卡时间")
    private Date fourLevelTime;
    /**
     * 第五关卡时间
     */
    @Excel(name = "第五关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第五关卡时间")
    private Date fiveLevelTime;
    /**
     * 第六关卡时间
     */
    @Excel(name = "第六关卡时间", width = 20, format = "yyyy-MM-dd")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "第六关卡时间")
    private Date sixLevelTime;
    /**
     * 删除状态
     */
    @Excel(name = "删除状态", width = 15)
    @Schema(description = "删除状态")
    private Integer delFlag;
    /**
     * 删除时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @TableField(updateStrategy = FieldStrategy.IGNORED)
    @Schema(description = "删除时间")
    private Date deleteTime;
    /**
     * 创建人
     */
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "username")
    @Schema(description = "创建人")
    private String createBy;
    /**
     * 创建时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间")
    private Date createTime;
    /**
     * 更新人
     */
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "username")
    @Schema(description = "更新人")
    private String updateBy;
    /**
     * 更新时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间")
    private Date updateTime;
    /**
     * 租户号
     */
    @Excel(name = "租户号", width = 15)
    @Schema(description = "租户号")
    private Integer tenantId;
    /**
     * 所属部门
     */
    @Dict(dictTable = "sys_depart", dicText = "depart_name", dicCode = "org_code")
    @Schema(description = "所属部门")
    private String sysOrgCode;
}
