package com.nationrel.modules.pdsc.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;
import org.jeecg.common.aspect.annotation.Dict;

import java.util.Date;

/**
 * @Description: 项目信息列表
 * @Author: zhangkai
 * @Date: 2024/5/29
 * @Version: V1.0
 */
@Builder
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
@Schema(description = "项目信息列表")
public class ProjectInfoListVo {

    /**
     * 主键
     */
    private String id;
    /**
     * PDSC编号
     */
    private String code;
    /**
     * PDSC名称
     */
    private String name;
    /**
     * 项目名称
     */
    private String projectName;
    /**
     * 产品名称
     */
    private String productName;
    /**
     * 项目类型
     */
    @Dict(dicCode = "nationrel_pdsc_project_type")
    private String projectType;
    /**
     * 项目阶段
     */
    private String projectStage;
    /**
     * CTQ等级
     */
    @Dict(dicCode = "nationrel_pdsc_ctq_grade")
    private String ctqGrade;
    /**
     * Owner
     */
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "id")
    private String owner;
    /**
     * 状态
     */
    @Dict(dicCode = "nationrel_pdsc_status")
    private String status;
    /**
     * 版本
     */
    private Integer version;
    /**
     * 下一版本
     */
    private Integer nextVersion;
    /**
     * 第零关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date zeroLevelTime;
    /**
     * 第一关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date oneLevelTime;
    /**
     * 第二关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date twoLevelTime;
    /**
     * 第三关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date threeLevelTime;
    /**
     * 第四关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date fourLevelTime;
    /**
     * 第五关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date fiveLevelTime;
    /**
     * 第六关卡时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd")
    private Date sixLevelTime;
    /**
     * 删除状态
     */
    private Integer delFlag;
    /**
     * 删除时间
     */
    private Date deleteTime;
    /**
     * 创建人
     */
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "username")
    private String createBy;
    /**
     * 创建时间
     */
    private Date createTime;
    /**
     * 更新人
     */
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "username")
    private String updateBy;
    /**
     * 更新时间
     */
    private Date updateTime;
    /**
     * 租户号
     */
    private Integer tenantId;
    /**
     * 所属部门
     */
    @Dict(dictTable = "sys_depart", dicText = "depart_name", dicCode = "org_code")
    private String sysOrgCode;
    /**
     * 按钮操作，0:编辑，1:查看
     */
    private Integer btnOperation;
}
