package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscActualPerformance;
import com.nationrel.modules.pdsc.service.IPdscActualPerformanceService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_actual_performance
 * @Author: nationrel
 * @Date: 2024-05-30
 * @Version: V1.0
 */
@Tag(name = "pdsc_actual_performance")
@RestController
@RequestMapping("/pdsc/pdscActualPerformance")
@Slf4j
public class PdscActualPerformanceController extends JeecgController<PdscActualPerformance, IPdscActualPerformanceService> {
    @Autowired
    private IPdscActualPerformanceService pdscActualPerformanceService;

    /**
     * 分页列表查询
     *
     * @param pdscActualPerformance
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_actual_performance-分页列表查询")
    @Operation(summary = "pdsc_actual_performance-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscActualPerformance>> queryPageList(PdscActualPerformance pdscActualPerformance,
                                                                      @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                      @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                      HttpServletRequest req) {
        QueryWrapper<PdscActualPerformance> queryWrapper = QueryGenerator.initQueryWrapper(pdscActualPerformance, req.getParameterMap());
        IPageExtField<PdscActualPerformance> page = new PageExtField<>(PdscActualPerformance.class, pageNo, pageSize);
        IPageExtField<PdscActualPerformance> pageList = pdscActualPerformanceService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscActualPerformance
     * @return
     */
    @AutoLog(value = "pdsc_actual_performance-添加")
    @Operation(summary = "pdsc_actual_performance-添加")
    @RequiresPermissions("pdsc:pdsc_actual_performance:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscActualPerformance pdscActualPerformance) {
        pdscActualPerformanceService.save(pdscActualPerformance);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscActualPerformance
     * @return
     */
    @AutoLog(value = "pdsc_actual_performance-编辑")
    @Operation(summary = "pdsc_actual_performance-编辑")
    @RequiresPermissions("pdsc:pdsc_actual_performance:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscActualPerformance pdscActualPerformance) {
        pdscActualPerformanceService.updateById(pdscActualPerformance);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_actual_performance-通过id删除")
    @Operation(summary = "pdsc_actual_performance-通过id删除")
    @RequiresPermissions("pdsc:pdsc_actual_performance:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscActualPerformanceService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_actual_performance-批量删除")
    @Operation(summary = "pdsc_actual_performance-批量删除")
    @RequiresPermissions("pdsc:pdsc_actual_performance:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscActualPerformanceService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_actual_performance-通过id查询")
    @Operation(summary = "pdsc_actual_performance-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscActualPerformance> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscActualPerformance pdscActualPerformance = pdscActualPerformanceService.getById(id);
        if (pdscActualPerformance == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscActualPerformance);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscActualPerformance
     */
    @RequiresPermissions("pdsc:pdsc_actual_performance:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscActualPerformance pdscActualPerformance) {
        return super.exportXls(request, pdscActualPerformance, PdscActualPerformance.class, "pdsc_actual_performance");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_actual_performance:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscActualPerformance.class);
    }

}
