package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscCtqDescription;
import com.nationrel.modules.pdsc.service.IPdscCtqDescriptionService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_ctq_description
 * @Author: nationrel
 * @Date: 2024-05-30
 * @Version: V1.0
 */
@Tag(name = "pdsc_ctq_description")
@RestController
@RequestMapping("/pdsc/pdscCtqDescription")
@Slf4j
public class PdscCtqDescriptionController extends JeecgController<PdscCtqDescription, IPdscCtqDescriptionService> {
    @Autowired
    private IPdscCtqDescriptionService pdscCtqDescriptionService;

    /**
     * 分页列表查询
     *
     * @param pdscCtqDescription
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_ctq_description-分页列表查询")
    @Operation(summary = "pdsc_ctq_description-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscCtqDescription>> queryPageList(PdscCtqDescription pdscCtqDescription,
                                                                   @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                   @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                   HttpServletRequest req) {
        QueryWrapper<PdscCtqDescription> queryWrapper = QueryGenerator.initQueryWrapper(pdscCtqDescription, req.getParameterMap());
        IPageExtField<PdscCtqDescription> page = new PageExtField<>(PdscCtqDescription.class, pageNo, pageSize);
        IPageExtField<PdscCtqDescription> pageList = pdscCtqDescriptionService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscCtqDescription
     * @return
     */
    @AutoLog(value = "pdsc_ctq_description-添加")
    @Operation(summary = "pdsc_ctq_description-添加")
    @RequiresPermissions("pdsc:pdsc_ctq_description:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscCtqDescription pdscCtqDescription) {
        pdscCtqDescriptionService.save(pdscCtqDescription);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscCtqDescription
     * @return
     */
    @AutoLog(value = "pdsc_ctq_description-编辑")
    @Operation(summary = "pdsc_ctq_description-编辑")
    @RequiresPermissions("pdsc:pdsc_ctq_description:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscCtqDescription pdscCtqDescription) {
        pdscCtqDescriptionService.updateById(pdscCtqDescription);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_ctq_description-通过id删除")
    @Operation(summary = "pdsc_ctq_description-通过id删除")
    @RequiresPermissions("pdsc:pdsc_ctq_description:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscCtqDescriptionService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_ctq_description-批量删除")
    @Operation(summary = "pdsc_ctq_description-批量删除")
    @RequiresPermissions("pdsc:pdsc_ctq_description:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscCtqDescriptionService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_ctq_description-通过id查询")
    @Operation(summary = "pdsc_ctq_description-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscCtqDescription> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscCtqDescription pdscCtqDescription = pdscCtqDescriptionService.getById(id);
        if (pdscCtqDescription == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscCtqDescription);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscCtqDescription
     */
    @RequiresPermissions("pdsc:pdsc_ctq_description:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscCtqDescription pdscCtqDescription) {
        return super.exportXls(request, pdscCtqDescription, PdscCtqDescription.class, "pdsc_ctq_description");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_ctq_description:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscCtqDescription.class);
    }

}
