package com.nationrel.modules.pdsc.controller;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscActualPerformance;
import com.nationrel.modules.pdsc.entity.PdscCtqProperty;
import com.nationrel.modules.pdsc.entity.PdscDefectConfine;
import com.nationrel.modules.pdsc.entity.PdscDesignRequire;
import com.nationrel.modules.pdsc.service.IPdscActualPerformanceService;
import com.nationrel.modules.pdsc.service.IPdscCtqPropertyService;
import com.nationrel.modules.pdsc.service.IPdscDefectConfineService;
import com.nationrel.modules.pdsc.service.IPdscDesignRequireService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.WrapperUtil;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_ctq_property
 * @Author: nationrel
 * @Date: 2024-05-30
 * @Version: V1.0
 */
@Tag(name = "pdsc_ctq_property")
@RestController
@RequestMapping("/pdsc/pdscCtqProperty")
@Slf4j
public class PdscCtqPropertyController extends JeecgController<PdscCtqProperty, IPdscCtqPropertyService> {
    @Autowired
    private IPdscCtqPropertyService pdscCtqPropertyService;
    @Autowired
    private IPdscDesignRequireService pdscDesignRequireService;
    @Autowired
    private IPdscDefectConfineService pdscDefectConfineService;
    @Autowired
    private IPdscActualPerformanceService pdscActualPerformanceService;

    /**
     * 分页列表查询
     *
     * @param pdscCtqProperty
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_ctq_property-分页列表查询")
    @Operation(summary = "pdsc_ctq_property-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscCtqProperty>> queryPageList(PdscCtqProperty pdscCtqProperty,
                                                                @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                HttpServletRequest req) {
        QueryWrapper<PdscCtqProperty> queryWrapper = QueryGenerator.initQueryWrapper(pdscCtqProperty, req.getParameterMap());
        IPageExtField<PdscCtqProperty> page = new PageExtField<>(PdscCtqProperty.class, pageNo, pageSize);
        IPageExtField<PdscCtqProperty> pageList = pdscCtqPropertyService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscCtqProperty
     * @return
     */
    @AutoLog(value = "pdsc_ctq_property-添加")
    @Operation(summary = "pdsc_ctq_property-添加")
    @RequiresPermissions("pdsc:pdsc_ctq_property:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscCtqProperty pdscCtqProperty) {
        pdscCtqPropertyService.save(pdscCtqProperty);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscCtqProperty
     * @return
     */
    @AutoLog(value = "pdsc_ctq_property-编辑")
    @Operation(summary = "pdsc_ctq_property-编辑")
    @RequiresPermissions("pdsc:pdsc_ctq_property:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscCtqProperty pdscCtqProperty) {
        PdscCtqProperty ctqProperty = pdscCtqPropertyService.getById(pdscCtqProperty);
        pdscCtqPropertyService.updateById(pdscCtqProperty);
        //类型切换，清空设计要求、缺陷率限制、实际性能
        if (ObjectUtil.notEqual(ctqProperty.getType(), pdscCtqProperty.getType())) {
            String pdscId = ctqProperty.getPdscId();
            pdscDesignRequireService.remove(WrapperUtil.toQueryWrapper(PdscDesignRequire.builder().pdscId(pdscId).build()));
            pdscDefectConfineService.remove(WrapperUtil.toQueryWrapper(PdscDefectConfine.builder().pdscId(pdscId).build()));
            pdscActualPerformanceService.remove(WrapperUtil.toQueryWrapper(PdscActualPerformance.builder().pdscId(pdscId).build()));
        }
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_ctq_property-通过id删除")
    @Operation(summary = "pdsc_ctq_property-通过id删除")
    @RequiresPermissions("pdsc:pdsc_ctq_property:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscCtqPropertyService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_ctq_property-批量删除")
    @Operation(summary = "pdsc_ctq_property-批量删除")
    @RequiresPermissions("pdsc:pdsc_ctq_property:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscCtqPropertyService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_ctq_property-通过id查询")
    @Operation(summary = "pdsc_ctq_property-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscCtqProperty> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscCtqProperty pdscCtqProperty = pdscCtqPropertyService.getById(id);
        if (pdscCtqProperty == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscCtqProperty);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscCtqProperty
     */
    @RequiresPermissions("pdsc:pdsc_ctq_property:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscCtqProperty pdscCtqProperty) {
        return super.exportXls(request, pdscCtqProperty, PdscCtqProperty.class, "pdsc_ctq_property");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_ctq_property:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscCtqProperty.class);
    }

}
