package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscDefectConfine;
import com.nationrel.modules.pdsc.service.IPdscDefectConfineService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_defect_confine
 * @Author: nationrel
 * @Date: 2024-05-30
 * @Version: V1.0
 */
@Tag(name = "pdsc_defect_confine")
@RestController
@RequestMapping("/pdsc/pdscDefectConfine")
@Slf4j
public class PdscDefectConfineController extends JeecgController<PdscDefectConfine, IPdscDefectConfineService> {
    @Autowired
    private IPdscDefectConfineService pdscDefectConfineService;

    /**
     * 分页列表查询
     *
     * @param pdscDefectConfine
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_defect_confine-分页列表查询")
    @Operation(summary = "pdsc_defect_confine-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscDefectConfine>> queryPageList(PdscDefectConfine pdscDefectConfine,
                                                                  @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                  @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                  HttpServletRequest req) {
        QueryWrapper<PdscDefectConfine> queryWrapper = QueryGenerator.initQueryWrapper(pdscDefectConfine, req.getParameterMap());
        IPageExtField<PdscDefectConfine> page = new PageExtField<>(PdscDefectConfine.class, pageNo, pageSize);
        IPageExtField<PdscDefectConfine> pageList = pdscDefectConfineService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscDefectConfine
     * @return
     */
    @AutoLog(value = "pdsc_defect_confine-添加")
    @Operation(summary = "pdsc_defect_confine-添加")
    @RequiresPermissions("pdsc:pdsc_defect_confine:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscDefectConfine pdscDefectConfine) {
        pdscDefectConfineService.save(pdscDefectConfine);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscDefectConfine
     * @return
     */
    @AutoLog(value = "pdsc_defect_confine-编辑")
    @Operation(summary = "pdsc_defect_confine-编辑")
    @RequiresPermissions("pdsc:pdsc_defect_confine:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscDefectConfine pdscDefectConfine) {
        pdscDefectConfineService.updateById(pdscDefectConfine);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_defect_confine-通过id删除")
    @Operation(summary = "pdsc_defect_confine-通过id删除")
    @RequiresPermissions("pdsc:pdsc_defect_confine:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscDefectConfineService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_defect_confine-批量删除")
    @Operation(summary = "pdsc_defect_confine-批量删除")
    @RequiresPermissions("pdsc:pdsc_defect_confine:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscDefectConfineService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_defect_confine-通过id查询")
    @Operation(summary = "pdsc_defect_confine-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscDefectConfine> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscDefectConfine pdscDefectConfine = pdscDefectConfineService.getById(id);
        if (pdscDefectConfine == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscDefectConfine);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscDefectConfine
     */
    @RequiresPermissions("pdsc:pdsc_defect_confine:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscDefectConfine pdscDefectConfine) {
        return super.exportXls(request, pdscDefectConfine, PdscDefectConfine.class, "pdsc_defect_confine");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_defect_confine:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscDefectConfine.class);
    }

}
