package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscDesignRequire;
import com.nationrel.modules.pdsc.service.IPdscDesignRequireService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_design_require
 * @Author: nationrel
 * @Date: 2024-05-30
 * @Version: V1.0
 */
@Tag(name = "pdsc_design_require")
@RestController
@RequestMapping("/pdsc/pdscDesignRequire")
@Slf4j
public class PdscDesignRequireController extends JeecgController<PdscDesignRequire, IPdscDesignRequireService> {
    @Autowired
    private IPdscDesignRequireService pdscDesignRequireService;

    /**
     * 分页列表查询
     *
     * @param pdscDesignRequire
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_design_require-分页列表查询")
    @Operation(summary = "pdsc_design_require-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscDesignRequire>> queryPageList(PdscDesignRequire pdscDesignRequire,
                                                                  @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                  @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                  HttpServletRequest req) {
        QueryWrapper<PdscDesignRequire> queryWrapper = QueryGenerator.initQueryWrapper(pdscDesignRequire, req.getParameterMap());
        IPageExtField<PdscDesignRequire> page = new PageExtField<>(PdscDesignRequire.class, pageNo, pageSize);
        IPageExtField<PdscDesignRequire> pageList = pdscDesignRequireService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscDesignRequire
     * @return
     */
    @AutoLog(value = "pdsc_design_require-添加")
    @Operation(summary = "pdsc_design_require-添加")
    @RequiresPermissions("pdsc:pdsc_design_require:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscDesignRequire pdscDesignRequire) {
        pdscDesignRequireService.save(pdscDesignRequire);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscDesignRequire
     * @return
     */
    @AutoLog(value = "pdsc_design_require-编辑")
    @Operation(summary = "pdsc_design_require-编辑")
    @RequiresPermissions("pdsc:pdsc_design_require:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscDesignRequire pdscDesignRequire) {
        pdscDesignRequireService.updateById(pdscDesignRequire);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_design_require-通过id删除")
    @Operation(summary = "pdsc_design_require-通过id删除")
    @RequiresPermissions("pdsc:pdsc_design_require:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscDesignRequireService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_design_require-批量删除")
    @Operation(summary = "pdsc_design_require-批量删除")
    @RequiresPermissions("pdsc:pdsc_design_require:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscDesignRequireService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_design_require-通过id查询")
    @Operation(summary = "pdsc_design_require-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscDesignRequire> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscDesignRequire pdscDesignRequire = pdscDesignRequireService.getById(id);
        if (pdscDesignRequire == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscDesignRequire);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscDesignRequire
     */
    @RequiresPermissions("pdsc:pdsc_design_require:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscDesignRequire pdscDesignRequire) {
        return super.exportXls(request, pdscDesignRequire, PdscDesignRequire.class, "pdsc_design_require");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_design_require:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscDesignRequire.class);
    }

}
