package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.PdscMaturity;
import com.nationrel.modules.pdsc.service.IPdscMaturityService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: pdsc_maturity
 * @Author: nationrel
 * @Date: 2024-06-05
 * @Version: V1.0
 */
@Tag(name = "pdsc_maturity")
@RestController
@RequestMapping("/pdsc/pdscMaturity")
@Slf4j
public class PdscMaturityController extends JeecgController<PdscMaturity, IPdscMaturityService> {
    @Autowired
    private IPdscMaturityService pdscMaturityService;

    /**
     * 分页列表查询
     *
     * @param pdscMaturity
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "pdsc_maturity-分页列表查询")
    @Operation(summary = "pdsc_maturity-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<PdscMaturity>> queryPageList(PdscMaturity pdscMaturity,
                                                             @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                             @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                             HttpServletRequest req) {
        QueryWrapper<PdscMaturity> queryWrapper = QueryGenerator.initQueryWrapper(pdscMaturity, req.getParameterMap());
        IPageExtField<PdscMaturity> page = new PageExtField<>(PdscMaturity.class, pageNo, pageSize);
        IPageExtField<PdscMaturity> pageList = pdscMaturityService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param pdscMaturity
     * @return
     */
    @AutoLog(value = "pdsc_maturity-添加")
    @Operation(summary = "pdsc_maturity-添加")
    @RequiresPermissions("pdsc:pdsc_maturity:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody PdscMaturity pdscMaturity) {
        pdscMaturityService.save(pdscMaturity);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param pdscMaturity
     * @return
     */
    @AutoLog(value = "pdsc_maturity-编辑")
    @Operation(summary = "pdsc_maturity-编辑")
    @RequiresPermissions("pdsc:pdsc_maturity:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody PdscMaturity pdscMaturity) {
        pdscMaturityService.updateById(pdscMaturity);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "pdsc_maturity-通过id删除")
    @Operation(summary = "pdsc_maturity-通过id删除")
    @RequiresPermissions("pdsc:pdsc_maturity:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        pdscMaturityService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "pdsc_maturity-批量删除")
    @Operation(summary = "pdsc_maturity-批量删除")
    @RequiresPermissions("pdsc:pdsc_maturity:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.pdscMaturityService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "pdsc_maturity-通过id查询")
    @Operation(summary = "pdsc_maturity-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<PdscMaturity> queryById(@RequestParam(name = "id", required = true) String id) {
        PdscMaturity pdscMaturity = pdscMaturityService.getById(id);
        if (pdscMaturity == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(pdscMaturity);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param pdscMaturity
     */
    @RequiresPermissions("pdsc:pdsc_maturity:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, PdscMaturity pdscMaturity) {
        return super.exportXls(request, pdscMaturity, PdscMaturity.class, "pdsc_maturity");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:pdsc_maturity:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, PdscMaturity.class);
    }

}
