package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.ProjectInfoPdsc;
import com.nationrel.modules.pdsc.req.PdscCleanRowReq;
import com.nationrel.modules.pdsc.req.PdscDeleteRowReq;
import com.nationrel.modules.pdsc.req.PdscPasteRowReq;
import com.nationrel.modules.pdsc.req.PdscSaveRowReq;
import com.nationrel.modules.pdsc.service.IProjectInfoPdscService;
import com.nationrel.modules.pdsc.vo.PdscListAllVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;
import java.util.List;

/**
 * @Description: project_info_pdsc
 * @Author: nationrel
 * @Date: 2024-05-28
 * @Version: V1.0
 */
@Tag(name = "project_info_pdsc")
@RestController
@RequestMapping("/pdsc/projectInfoPdsc")
@Slf4j
public class ProjectInfoPdscController extends JeecgController<ProjectInfoPdsc, IProjectInfoPdscService> {
    @Autowired
    private IProjectInfoPdscService projectInfoPdscService;

    /**
     * 分页列表查询
     *
     * @param projectInfoPdsc
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "project_info_pdsc-分页列表查询")
    @Operation(summary = "project_info_pdsc-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<ProjectInfoPdsc>> queryPageList(ProjectInfoPdsc projectInfoPdsc,
                                                                @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                HttpServletRequest req) {
        QueryWrapper<ProjectInfoPdsc> queryWrapper = QueryGenerator.initQueryWrapper(projectInfoPdsc, req.getParameterMap());
        IPageExtField<ProjectInfoPdsc> page = new PageExtField<>(ProjectInfoPdsc.class, pageNo, pageSize);
        IPageExtField<ProjectInfoPdsc> pageList = projectInfoPdscService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    @Operation(summary = "project_info_pdsc-全部列表查询")
    @RequestMapping(value = "/listAll", method = RequestMethod.GET)
    public Result<List<PdscListAllVo>> listAll(ProjectInfoPdsc projectInfoPdsc) {
        return Result.OK(projectInfoPdscService.listAll(projectInfoPdsc));
    }

    /**
     * 添加
     *
     * @param projectInfoPdsc
     * @return
     */
    @AutoLog(value = "project_info_pdsc-添加")
    @Operation(summary = "project_info_pdsc-添加")
    @RequiresPermissions("pdsc:project_info_pdsc:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody ProjectInfoPdsc projectInfoPdsc) {
        projectInfoPdscService.save(projectInfoPdsc);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param projectInfoPdsc
     * @return
     */
    @AutoLog(value = "project_info_pdsc-编辑")
    @Operation(summary = "project_info_pdsc-编辑")
    @RequiresPermissions("pdsc:project_info_pdsc:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody ProjectInfoPdsc projectInfoPdsc) {
        projectInfoPdscService.updateById(projectInfoPdsc);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "project_info_pdsc-通过id删除")
    @Operation(summary = "project_info_pdsc-通过id删除")
    @RequiresPermissions("pdsc:project_info_pdsc:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        projectInfoPdscService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "project_info_pdsc-批量删除")
    @Operation(summary = "project_info_pdsc-批量删除")
    @RequiresPermissions("pdsc:project_info_pdsc:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.projectInfoPdscService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "project_info_pdsc-通过id查询")
    @Operation(summary = "project_info_pdsc-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<ProjectInfoPdsc> queryById(@RequestParam(name = "id", required = true) String id) {
        ProjectInfoPdsc projectInfoPdsc = projectInfoPdscService.getById(id);
        if (projectInfoPdsc == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(projectInfoPdsc);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param projectInfoPdsc
     */
    @RequiresPermissions("pdsc:project_info_pdsc:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ProjectInfoPdsc projectInfoPdsc) {
        return super.exportXls(request, projectInfoPdsc, ProjectInfoPdsc.class, "pdsc_info_pdsc");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:project_info_pdsc:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ProjectInfoPdsc.class);
    }

    @AutoLog(value = "PDSC-插入行")
    @Operation(summary = "PDSC-插入行")
    @RequestMapping(value = "/saveRow", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> saveRow(@RequestBody @Valid PdscSaveRowReq req) {
        projectInfoPdscService.saveRow(req);
        return Result.OK(MessageUtils.get("nationrel_save_success"));
    }

    @AutoLog(value = "PDSC-删除行")
    @Operation(summary = "PDSC-删除行")
    @RequestMapping(value = "/deleteRow", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> deleteRow(@RequestBody @Valid PdscDeleteRowReq req) {
        projectInfoPdscService.deleteRow(req);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    @AutoLog(value = "PDSC-清除行")
    @Operation(summary = "PDSC-清除行")
    @RequestMapping(value = "/cleanRow", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> cleanRow(@RequestBody @Valid PdscCleanRowReq req) {
        projectInfoPdscService.cleanRow(req);
        return Result.OK(MessageUtils.get("nationrel_clean_up_success"));
    }

    @AutoLog(value = "PDSC-粘贴行")
    @Operation(summary = "PDSC-粘贴行")
    @RequestMapping(value = "/pasteRow", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> pasteRow(@RequestBody @Valid PdscPasteRowReq req) {
        projectInfoPdscService.pasteRow(req);
        return Result.OK(MessageUtils.get("nationrel_operation_success"));
    }
}
