package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.ProjectInfoPerson;
import com.nationrel.modules.pdsc.service.IProjectInfoPersonService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;
import java.util.List;

/**
 * @Description: project_info_person
 * @Author: nationrel
 * @Date: 2024-05-27
 * @Version: V1.0
 */
@Tag(name = "project_info_person")
@RestController
@RequestMapping("/pdsc/projectInfoPerson")
@Slf4j
public class ProjectInfoPersonController extends JeecgController<ProjectInfoPerson, IProjectInfoPersonService> {
    @Autowired
    private IProjectInfoPersonService projectInfoPersonService;

    /**
     * 分页列表查询
     *
     * @param projectInfoPerson
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "project_info_person-分页列表查询")
    @Operation(summary = "project_info_person-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<ProjectInfoPerson>> queryPageList(ProjectInfoPerson projectInfoPerson,
                                                                  @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                  @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                  HttpServletRequest req) {
        QueryWrapper<ProjectInfoPerson> queryWrapper = QueryGenerator.initQueryWrapper(projectInfoPerson, req.getParameterMap());
        IPageExtField<ProjectInfoPerson> page = new PageExtField<>(ProjectInfoPerson.class, pageNo, pageSize);
        IPageExtField<ProjectInfoPerson> pageList = projectInfoPersonService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param projectInfoPerson
     * @return
     */
    @AutoLog(value = "project_info_person-添加")
    @Operation(summary = "project_info_person-添加")
    @RequiresPermissions("pdsc:project_info_person:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody ProjectInfoPerson projectInfoPerson) {
        projectInfoPersonService.save(projectInfoPerson);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    @AutoLog(value = "project_info_person-批量添加")
    @Operation(summary = "project_info_person-批量添加")
    @RequiresPermissions("pdsc:project_info_person:add")
    @PostMapping(value = "/saveBatch")
    public Result<String> saveBatch(@RequestBody List<ProjectInfoPerson> projectInfoPersons) {
        projectInfoPersonService.saveBatch(projectInfoPersons);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param projectInfoPerson
     * @return
     */
    @AutoLog(value = "project_info_person-编辑")
    @Operation(summary = "project_info_person-编辑")
    @RequiresPermissions("pdsc:project_info_person:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody ProjectInfoPerson projectInfoPerson) {
        projectInfoPersonService.updateById(projectInfoPerson);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "project_info_person-通过id删除")
    @Operation(summary = "project_info_person-通过id删除")
    @RequiresPermissions("pdsc:project_info_person:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        projectInfoPersonService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "project_info_person-批量删除")
    @Operation(summary = "project_info_person-批量删除")
    @RequiresPermissions("pdsc:project_info_person:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.projectInfoPersonService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "project_info_person-通过id查询")
    @Operation(summary = "project_info_person-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<ProjectInfoPerson> queryById(@RequestParam(name = "id", required = true) String id) {
        ProjectInfoPerson projectInfoPerson = projectInfoPersonService.getById(id);
        if (projectInfoPerson == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(projectInfoPerson);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param projectInfoPerson
     */
    @RequiresPermissions("pdsc:project_info_person:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ProjectInfoPerson projectInfoPerson) {
        return super.exportXls(request, projectInfoPerson, ProjectInfoPerson.class, "团队成员");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:project_info_person:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ProjectInfoPerson.class);
    }

}
