package com.nationrel.modules.pdsc.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.nationrel.modules.pdsc.entity.ProjectInfoVersionRecord;
import com.nationrel.modules.pdsc.service.IProjectInfoVersionRecordService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.api.PageExtField;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;

/**
 * @Description: project_info_version_record
 * @Author: nationrel
 * @Date: 2024-05-28
 * @Version: V1.0
 */
@Tag(name = "project_info_version_record")
@RestController
@RequestMapping("/pdsc/projectInfoVersionRecord")
@Slf4j
public class ProjectInfoVersionRecordController extends JeecgController<ProjectInfoVersionRecord, IProjectInfoVersionRecordService> {
    @Autowired
    private IProjectInfoVersionRecordService projectInfoVersionRecordService;

    /**
     * 分页列表查询
     *
     * @param projectInfoVersionRecord
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "project_info_version_record-分页列表查询")
    @Operation(summary = "project_info_version_record-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPageExtField<ProjectInfoVersionRecord>> queryPageList(ProjectInfoVersionRecord projectInfoVersionRecord,
                                                                         @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                                         @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                                         HttpServletRequest req) {
        QueryWrapper<ProjectInfoVersionRecord> queryWrapper = QueryGenerator.initQueryWrapper(projectInfoVersionRecord, req.getParameterMap());
        IPageExtField<ProjectInfoVersionRecord> page = new PageExtField<>(ProjectInfoVersionRecord.class, pageNo, pageSize);
        IPageExtField<ProjectInfoVersionRecord> pageList = projectInfoVersionRecordService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param projectInfoVersionRecord
     * @return
     */
    @AutoLog(value = "project_info_version_record-添加")
    @Operation(summary = "project_info_version_record-添加")
    @RequiresPermissions("pdsc:project_info_version_record:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody ProjectInfoVersionRecord projectInfoVersionRecord) {
        projectInfoVersionRecordService.save(projectInfoVersionRecord);
        return Result.OK(MessageUtils.get("nationrel_add_success"));
    }

    /**
     * 编辑
     *
     * @param projectInfoVersionRecord
     * @return
     */
    @AutoLog(value = "project_info_version_record-编辑")
    @Operation(summary = "project_info_version_record-编辑")
    @RequiresPermissions("pdsc:project_info_version_record:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody ProjectInfoVersionRecord projectInfoVersionRecord) {
        projectInfoVersionRecordService.updateById(projectInfoVersionRecord);
        return Result.OK(MessageUtils.get("nationrel_edit_success"));
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "project_info_version_record-通过id删除")
    @Operation(summary = "project_info_version_record-通过id删除")
    @RequiresPermissions("pdsc:project_info_version_record:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        projectInfoVersionRecordService.removeById(id);
        return Result.OK(MessageUtils.get("nationrel_delete_success"));
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "project_info_version_record-批量删除")
    @Operation(summary = "project_info_version_record-批量删除")
    @RequiresPermissions("pdsc:project_info_version_record:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.projectInfoVersionRecordService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(MessageUtils.get("nationrel_delete_batch_success"));
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "project_info_version_record-通过id查询")
    @Operation(summary = "project_info_version_record-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<ProjectInfoVersionRecord> queryById(@RequestParam(name = "id", required = true) String id) {
        ProjectInfoVersionRecord projectInfoVersionRecord = projectInfoVersionRecordService.getById(id);
        if (projectInfoVersionRecord == null) {
            return Result.error(MessageUtils.get("nationrel_no_found_data"));
        }
        return Result.OK(projectInfoVersionRecord);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param projectInfoVersionRecord
     */
    @RequiresPermissions("pdsc:project_info_version_record:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ProjectInfoVersionRecord projectInfoVersionRecord) {
        return super.exportXls(request, projectInfoVersionRecord, ProjectInfoVersionRecord.class, "版本记录");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("pdsc:project_info_version_record:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ProjectInfoVersionRecord.class);
    }

}
