package com.nationrel.modules.pdsc.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.nationrel.modules.pdsc.entity.ProjectInfo;
import com.nationrel.modules.pdsc.req.ProjectInfoActivateReq;
import com.nationrel.modules.pdsc.req.ProjectInfoListReq;
import com.nationrel.modules.pdsc.req.ProjectInfoReleaseReq;
import com.nationrel.modules.pdsc.vo.ProjectInfoListVo;
import com.nationrel.modules.pdsc.vo.ProjectInfoVo;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.jeecg.common.api.IPageExtField;
import org.springframework.web.servlet.ModelAndView;

import java.io.IOException;

/**
 * @Description: 项目信息
 * @Author: nationrel
 * @Date: 2024-03-26
 * @Version: V1.0
 */
public interface IProjectInfoService extends IService<ProjectInfo> {

    /**
     * 分页列表查询
     *
     * @param req  请求
     * @param page 分页
     * @return 结果
     */
    IPageExtField<ProjectInfoListVo> list(ProjectInfoListReq req, IPageExtField<ProjectInfo> page);

    /**
     * 添加
     *
     * @param projectInfo 实体对象
     */
    void saveProjectInfo(ProjectInfo projectInfo);

    /**
     * 项目发布
     *
     * @param req 请求
     */
    void release(ProjectInfoReleaseReq req);

    /**
     * 删除
     *
     * @param id 主键
     */
    void delete(String id);

    /**
     * 批量删除
     *
     * @param ids 主键集合
     */
    void deleteBatch(String ids);

    /**
     * 项目激活
     *
     * @param req 请求
     */
    void activate(ProjectInfoActivateReq req);

    /**
     * 通过id查询
     *
     * @param id 主键
     * @return 结果
     */
    ProjectInfoVo queryById(String id);

    /**
     * 导出excel
     *
     * @param response servlet响应
     * @param req     请求
     */
    void exportXls(HttpServletResponse response, ProjectInfoListReq req) throws Exception;
}
