package com.nationrel.modules.pdsc.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.nationrel.modules.pdsc.api.NationrelSystemApi;
import com.nationrel.modules.pdsc.entity.*;
import com.nationrel.modules.pdsc.mapper.ProjectInfoPdscMapper;
import com.nationrel.modules.pdsc.req.PdscCleanRowReq;
import com.nationrel.modules.pdsc.req.PdscDeleteRowReq;
import com.nationrel.modules.pdsc.req.PdscPasteRowReq;
import com.nationrel.modules.pdsc.req.PdscSaveRowReq;
import com.nationrel.modules.pdsc.resp.SysUserResp;
import com.nationrel.modules.pdsc.service.*;
import com.nationrel.modules.pdsc.vo.*;
import org.jeecg.common.util.WrapperUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * @Description: project_info_pdsc
 * @Author: nationrel
 * @Date: 2024-05-28
 * @Version: V1.0
 */
@Service
public class ProjectInfoPdscServiceImpl extends ServiceImpl<ProjectInfoPdscMapper, ProjectInfoPdsc> implements IProjectInfoPdscService {

    @Autowired
    @Lazy
    private IProjectInfoService projectInfoService;
    @Autowired
    private IPdscCtqDescriptionService pdscCtqDescriptionService;
    @Autowired
    private IPdscCtqPropertyService pdscCtqPropertyService;
    @Autowired
    private IPdscDesignRequireService pdscDesignRequireService;
    @Autowired
    private IPdscDefectConfineService pdscDefectConfineService;
    @Autowired
    private IPdscActualPerformanceService pdscActualPerformanceService;
    @Autowired
    private IPdscMaturityService pdscMaturityService;
    @Autowired
    private NationrelSystemApi nationrelSystemApi;

    /**
     * PDSC-插入行
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveRow(PdscSaveRowReq req) {
        String projectId = req.getProjectId();
        Integer sortNo = (req.getSortNo() + req.getOptType());
        List<ProjectInfoPdsc> projectInfoPdscList = list(WrapperUtil.toQueryWrapper(
                ProjectInfoPdsc.builder().projectId(projectId).build()));
        List<ProjectInfoPdsc> updatePdscList = projectInfoPdscList.stream()
                .filter(v -> v.getSortNo() >= sortNo).toList();
        updatePdscList.forEach(v -> v.setSortNo((v.getSortNo() + 1)));
        if (CollectionUtil.isNotEmpty(updatePdscList)) updateBatchById(updatePdscList);
        save(ProjectInfoPdsc.builder().projectId(projectId).sortNo(sortNo).build());
    }

    /**
     * PDSC-删除行
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteRow(PdscDeleteRowReq req) {
        String id = req.getId();
        String projectId = req.getProjectId();
        ProjectInfoPdsc projectInfoPdsc = getById(id);
        List<ProjectInfoPdsc> projectInfoPdscList = list(WrapperUtil.toQueryWrapper(
                ProjectInfoPdsc.builder().projectId(projectId).build()));
        List<ProjectInfoPdsc> updatePdscList = projectInfoPdscList.stream()
                .filter(v -> v.getSortNo() >= projectInfoPdsc.getSortNo()).toList();
        updatePdscList.forEach(v -> v.setSortNo((v.getSortNo() - 1)));
        if (CollectionUtil.isNotEmpty(updatePdscList)) updateBatchById(updatePdscList);
        removeById(id);
    }

    /**
     * 全部列表查询
     *
     * @param projectInfoPdsc 请求
     * @return 结果
     */
    @Override
    public List<PdscListAllVo> listAll(ProjectInfoPdsc projectInfoPdsc) {
        String projectId = projectInfoPdsc.getProjectId();
        LambdaQueryWrapper<ProjectInfoPdsc> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ProjectInfoPdsc::getProjectId, projectId);
        queryWrapper.orderByAsc(ProjectInfoPdsc::getSortNo);
        List<PdscListAllVo> pdscListAllVos = list(queryWrapper).stream().map(v -> {
            PdscListAllVo vo = new PdscListAllVo();
            BeanUtil.copyProperties(v, vo);
            return vo;
        }).toList();
        ProjectInfoVo projectInfoVo = projectInfoService.queryById(projectId);
        List<String> pdscIds = pdscListAllVos.stream().map(PdscListAllVo::getId).toList();
        if (CollectionUtil.isEmpty(pdscIds)) return new ArrayList<>();
        Map<String, PdscCtqDescriptionVo> ctqDescriptionMap = getCtqDescriptionMap(pdscIds);
        Map<String, PdscCtqPropertyVo> ctqPropertyMap = getCtqPropertyMap(pdscIds);
        Map<String, PdscDesignRequireVo> designRequireMap = getDesignRequireMap(pdscIds);
        Map<String, PdscDefectConfineVo> defectConfineMap = getPdscDefectConfineMap(pdscIds);
        Map<String, PdscActualPerformanceVo> actualPerformanceMap = getPdscActualPerformanceMap(pdscIds);
        Map<String, PdscMaturityVo> maturityMap = getPdscMaturityMap(pdscIds);
        pdscListAllVos.forEach(v -> {
            v.setProjectType(projectInfoVo.getProjectType());
            v.setProjectStage(Integer.valueOf(projectInfoVo.getProjectStage()));
            v.setBtnOperation(projectInfoVo.getBtnOperation());
            v.setCtqGrade(projectInfoVo.getCtqGrade());
            v.setCtqDescription(ctqDescriptionMap.get(v.getId()));
            v.setCtqProperty(ctqPropertyMap.get(v.getId()));
            v.setDesignRequire(designRequireMap.get(v.getId()));
            v.setDefectConfine(defectConfineMap.get(v.getId()));
            v.setActualPerformance(actualPerformanceMap.get(v.getId()));
            v.setMaturity(maturityMap.get(v.getId()));
        });
        return pdscListAllVos;
    }

    /**
     * PDSC-清除行
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void cleanRow(PdscCleanRowReq req) {
        String id = req.getId();
        pdscCtqDescriptionService.remove(WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(id).build()));
        pdscCtqPropertyService.remove(WrapperUtil.toQueryWrapper(PdscCtqProperty.builder().pdscId(id).build()));
        pdscDesignRequireService.remove(WrapperUtil.toQueryWrapper(PdscDesignRequire.builder().pdscId(id).build()));
        pdscDefectConfineService.remove(WrapperUtil.toQueryWrapper(PdscDefectConfine.builder().pdscId(id).build()));
        pdscActualPerformanceService.remove(WrapperUtil.toQueryWrapper(PdscActualPerformance.builder().pdscId(id).build()));
        pdscMaturityService.remove(WrapperUtil.toQueryWrapper(PdscMaturity.builder().pdscId(id).build()));
        updateById(ProjectInfoPdsc.builder().id(id).code(StrUtil.EMPTY).priority(StrUtil.EMPTY).description(StrUtil.EMPTY).build());
    }

    /**
     * PDSC-粘贴行
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void pasteRow(PdscPasteRowReq req) {
        String sourceId = req.getSourceId();
        String targetId = req.getTargetId();
        Integer optType = req.getOptType();
        //复制一份
        copyProjectInfoPdsc(sourceId, targetId);
        copyPdscCtqDescription(sourceId, targetId);
        copyPdscCtqProperty(sourceId, targetId);
        copyPdscDesignRequire(sourceId, targetId);
        copyPdscDefectConfine(sourceId, targetId);
        copyPdscActualPerformance(sourceId, targetId);
        copyPdscMaturity(sourceId, targetId);
        if (optType == 2) {//剪切
            cleanRow(PdscCleanRowReq.builder().id(sourceId).build());
        }
    }

    /**
     * 查询CTQ描述Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscCtqDescriptionVo> getCtqDescriptionMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscCtqDescription> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscCtqDescription::getPdscId, pdscIds);
        return pdscCtqDescriptionService.list(queryWrapper).stream().collect(Collectors.toMap(
                PdscCtqDescription::getPdscId, v -> {
                    PdscCtqDescriptionVo vo = new PdscCtqDescriptionVo();
                    BeanUtil.copyProperties(v, vo);
                    return vo;
                })
        );
    }

    /**
     * 查询CTQ属性Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscCtqPropertyVo> getCtqPropertyMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscCtqProperty> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscCtqProperty::getPdscId, pdscIds);
        List<PdscCtqProperty> ctqProperties = pdscCtqPropertyService.list(queryWrapper);
        List<String> owners = ctqProperties.stream().map(PdscCtqProperty::getOwner)
                .filter(StrUtil::isNotEmpty).distinct().toList();
        Map<String, String> sysUserMap = new HashMap<>();
        if (CollectionUtil.isNotEmpty(owners)) {
            sysUserMap.putAll(nationrelSystemApi.listSysUserByIds(owners).stream()
                    .collect(Collectors.toMap(SysUserResp::getId, SysUserResp::getRealname)));
        }
        return ctqProperties.stream().collect(Collectors.toMap(
                PdscCtqProperty::getPdscId, v -> {
                    PdscCtqPropertyVo vo = new PdscCtqPropertyVo();
                    BeanUtil.copyProperties(v, vo);
                    if (CollectionUtil.isNotEmpty(sysUserMap)) {
                        vo.setOwner_dictText(sysUserMap.getOrDefault(vo.getOwner(), StrUtil.EMPTY));
                    }
                    return vo;
                })
        );
    }

    /**
     * 查询设计要求Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscDesignRequireVo> getDesignRequireMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscDesignRequire> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscDesignRequire::getPdscId, pdscIds);
        return pdscDesignRequireService.list(queryWrapper).stream().collect(Collectors.toMap(
                PdscDesignRequire::getPdscId, v -> {
                    PdscDesignRequireVo vo = new PdscDesignRequireVo();
                    BeanUtil.copyProperties(v, vo);
                    return vo;
                })
        );
    }

    /**
     * 查询缺陷率限制Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscDefectConfineVo> getPdscDefectConfineMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscDefectConfine> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscDefectConfine::getPdscId, pdscIds);
        return pdscDefectConfineService.list(queryWrapper).stream().collect(Collectors.toMap(
                PdscDefectConfine::getPdscId, v -> {
                    PdscDefectConfineVo vo = new PdscDefectConfineVo();
                    BeanUtil.copyProperties(v, vo);
                    return vo;
                })
        );
    }

    /**
     * 查询实际性能Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscActualPerformanceVo> getPdscActualPerformanceMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscActualPerformance> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscActualPerformance::getPdscId, pdscIds);
        return pdscActualPerformanceService.list(queryWrapper).stream().collect(Collectors.toMap(
                PdscActualPerformance::getPdscId, v -> {
                    PdscActualPerformanceVo vo = new PdscActualPerformanceVo();
                    BeanUtil.copyProperties(v, vo);
                    return vo;
                })
        );
    }

    /**
     * 查询实成熟度Map
     *
     * @param pdscIds pdsc主键
     * @return 结果
     */
    private Map<String, PdscMaturityVo> getPdscMaturityMap(List<String> pdscIds) {
        LambdaQueryWrapper<PdscMaturity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscMaturity::getPdscId, pdscIds);
        return pdscMaturityService.list(queryWrapper).stream().collect(Collectors.toMap(
                PdscMaturity::getPdscId, v -> {
                    PdscMaturityVo vo = new PdscMaturityVo();
                    BeanUtil.copyProperties(v, vo);
                    return vo;
                })
        );
    }

    /**
     * 拷贝-PDSC
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyProjectInfoPdsc(String sourceId, String targetId) {
        ProjectInfoPdsc source = getOne(
                WrapperUtil.toQueryWrapper(ProjectInfoPdsc.builder().id(sourceId).build()));
        ProjectInfoPdsc target = getOne(
                WrapperUtil.toQueryWrapper(ProjectInfoPdsc.builder().id(targetId).build()));
        BeanUtil.copyProperties(source, target, "id", "projectId", "sortNo", "createBy", "createTime");
        updateById(target);
    }

    /**
     * 拷贝-CTQ描述
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscCtqDescription(String sourceId, String targetId) {
        PdscCtqDescription source = pdscCtqDescriptionService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscCtqDescription target = pdscCtqDescriptionService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscCtqDescription.builder().pdscId(targetId).build();
        BeanUtils.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscCtqDescriptionService.saveOrUpdate(target);
    }

    /**
     * 拷贝-CTQ属性
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscCtqProperty(String sourceId, String targetId) {
        PdscCtqProperty source = pdscCtqPropertyService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscCtqProperty target = pdscCtqPropertyService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscCtqProperty.builder().pdscId(targetId).build();
        BeanUtil.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscCtqPropertyService.saveOrUpdate(target);
    }

    /**
     * 拷贝-缺陷率限制
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscDefectConfine(String sourceId, String targetId) {
        PdscDefectConfine source = pdscDefectConfineService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscDefectConfine target = pdscDefectConfineService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscDefectConfine.builder().pdscId(targetId).build();
        BeanUtil.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscDefectConfineService.saveOrUpdate(target);
    }

    /**
     * 拷贝-设计要求
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscDesignRequire(String sourceId, String targetId) {
        PdscDesignRequire source = pdscDesignRequireService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscDesignRequire target = pdscDesignRequireService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscDesignRequire.builder().pdscId(targetId).build();
        BeanUtil.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscDesignRequireService.saveOrUpdate(target);
    }

    /**
     * 拷贝-实际性能
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscActualPerformance(String sourceId, String targetId) {
        PdscActualPerformance source = pdscActualPerformanceService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscActualPerformance target = pdscActualPerformanceService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscActualPerformance.builder().pdscId(targetId).build();
        BeanUtil.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscActualPerformanceService.saveOrUpdate(target);
    }

    /**
     * 拷贝-成熟度
     *
     * @param sourceId 来源ID
     * @param targetId 目标ID
     */
    private void copyPdscMaturity(String sourceId, String targetId) {
        PdscMaturity source = pdscMaturityService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(sourceId).build()));
        PdscMaturity target = pdscMaturityService.getOne(
                WrapperUtil.toQueryWrapper(PdscCtqDescription.builder().pdscId(targetId).build()));
        if (ObjectUtil.isNull(target)) target = PdscMaturity.builder().pdscId(targetId).build();
        BeanUtil.copyProperties(source, target, "id", "pdscId", "createBy", "createTime");
        pdscMaturityService.saveOrUpdate(target);
    }
}
