package com.nationrel.modules.pdsc.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.nationrel.modules.pdsc.constant.PDSCConstant;
import com.nationrel.modules.pdsc.entity.*;
import com.nationrel.modules.pdsc.enums.ProjectStatuseEnum;
import com.nationrel.modules.pdsc.mapper.ProjectInfoMapper;
import com.nationrel.modules.pdsc.req.ProjectInfoActivateReq;
import com.nationrel.modules.pdsc.req.ProjectInfoListReq;
import com.nationrel.modules.pdsc.req.ProjectInfoReleaseReq;
import com.nationrel.modules.pdsc.service.*;
import com.nationrel.modules.pdsc.vo.ProjectInfoListVo;
import com.nationrel.modules.pdsc.vo.ProjectInfoVo;
import jakarta.annotation.Resource;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.CommonAPI;
import org.jeecg.common.api.IPageExtField;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.constant.SymbolConstant;
import org.jeecg.common.constant.enums.FileTypeEnum;
import org.jeecg.common.system.vo.DictModel;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.WrapperUtil;
import org.jeecg.config.i18n.MessageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @Description: 项目信息
 * @Author: nationrel
 * @Date: 2024-03-26
 * @Version: V1.0
 */
@Service
public class ProjectInfoServiceImpl extends ServiceImpl<ProjectInfoMapper, ProjectInfo> implements IProjectInfoService {

    @Autowired
    private IProjectInfoPdscService projectInfoPdscService;
    @Autowired
    private IProjectInfoPersonService projectInfoPersonService;
    @Autowired
    private IProjectInfoVersionRecordService projectInfoVersionRecordService;
    @Autowired
    private IPdscActualPerformanceService pdscActualPerformanceService;
    @Autowired
    private IPdscCtqDescriptionService pdscCtqDescriptionService;
    @Autowired
    private IPdscCtqPropertyService pdscCtqPropertyService;
    @Autowired
    private IPdscDefectConfineService pdscDefectConfineService;
    @Autowired
    private IPdscDesignRequireService pdscDesignRequireService;
    @Autowired
    private IPdscMaturityService pdscMaturityService;
    @Autowired
    private ProjectInfoMapper projectInfoMapper;
    @Resource
    private CommonAPI commonApi;

    /**
     * 分页列表查询
     *
     * @param req  请求
     * @param page 分页
     * @return 结果
     */
    @Override
    public IPageExtField<ProjectInfoListVo> list(ProjectInfoListReq req, IPageExtField<ProjectInfo> page) {
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        req.setUserId(user.getId());
        return (IPageExtField<ProjectInfoListVo>) projectInfoMapper.list(req, page).convert(v -> {
            ProjectInfoListVo vo = new ProjectInfoListVo();
            BeanUtil.copyProperties(v, vo);
            return vo;
        });
    }

    /**
     * 添加
     *
     * @param projectInfo 实体对象
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveProjectInfo(ProjectInfo projectInfo) {
        save(projectInfo);
        List<ProjectInfoPdsc> projectInfoPdscList = new ArrayList<>() {{
            add(ProjectInfoPdsc.builder().projectId(projectInfo.getId()).sortNo(1).build());
            add(ProjectInfoPdsc.builder().projectId(projectInfo.getId()).sortNo(2).build());
            add(ProjectInfoPdsc.builder().projectId(projectInfo.getId()).sortNo(3).build());
        }};
        //默认插入三条
        projectInfoPdscService.saveBatch(projectInfoPdscList);
    }

    /**
     * 项目发布
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void release(ProjectInfoReleaseReq req) {
        ProjectInfo projectInfo = getById(req.getId());
        projectInfo.setStatus(ProjectStatuseEnum.RELEASE.getType());
        updateById(projectInfo);
    }

    /**
     * 删除
     *
     * @param id 主键
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delete(String id) {
        ProjectInfo projectInfo = getById(id);
        projectInfo.setDelFlag(CommonConstant.DEL_FLAG_1);
        projectInfo.setDeleteTime(new Date());
        updateById(projectInfo);
        if (projectInfo.getVersion() > 1) {
            ProjectInfo lastProjectInfo = getOne(WrapperUtil.toQueryWrapper(
                    ProjectInfo.builder().code(projectInfo.getCode()).version((projectInfo.getVersion() - 1)).build()));
            lastProjectInfo.setNextVersion(PDSCConstant.PROJECT_NEXT_VERSION_NOT_EXIST);
            updateById(lastProjectInfo);
        }
    }

    /**
     * 批量删除
     *
     * @param ids 主键集合
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteBatch(String ids) {
        List<ProjectInfo> projectInfos = listByIds(Arrays.asList(ids.split(",")));
        Date curDate = new Date();
        projectInfos.forEach(v -> {
            v.setDelFlag(CommonConstant.DEL_FLAG_1);
            v.setDeleteTime(curDate);
        });
        updateBatchById(projectInfos);
        List<ProjectInfo> lastProjectInfos = projectInfos.stream().filter(v -> v.getVersion() > 1).toList();
        if (CollectionUtil.isEmpty(lastProjectInfos)) return;
        List<ProjectInfo> batchUpdateLastProjectInfos = new ArrayList<>();
        lastProjectInfos.forEach(v -> {
            ProjectInfo lastProjectInfo = getOne(WrapperUtil.toQueryWrapper(
                    ProjectInfo.builder().code(v.getCode()).version((v.getVersion() - 1)).build()));
            lastProjectInfo.setNextVersion(PDSCConstant.PROJECT_NEXT_VERSION_NOT_EXIST);
            batchUpdateLastProjectInfos.add(lastProjectInfo);
        });
        updateBatchById(batchUpdateLastProjectInfos);
    }

    /**
     * 项目激活
     *
     * @param req 请求
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void activate(ProjectInfoActivateReq req) {
        String projectId = req.getId();
        ProjectInfo projectInfo = getById(projectId);
        projectInfo.setNextVersion(PDSCConstant.PROJECT_NEXT_VERSION_EXIST);
        updateById(projectInfo);
        //拷贝项目信息
        ProjectInfo newProjectInfo = new ProjectInfo();
        BeanUtil.copyProperties(projectInfo, newProjectInfo);
        Integer nextVersion = (newProjectInfo.getVersion() + 1);
        newProjectInfo.setId(StrUtil.EMPTY);
        newProjectInfo.setStatus(ProjectStatuseEnum.UNDER_PREPARATION.getType());
        newProjectInfo.setVersion(nextVersion);
        newProjectInfo.setNextVersion(PDSCConstant.PROJECT_NEXT_VERSION_NOT_EXIST);
        newProjectInfo.setCreateBy(null);
        newProjectInfo.setCreateTime(null);
        newProjectInfo.setUpdateBy(null);
        newProjectInfo.setUpdateTime(null);
        save(newProjectInfo);
        String newProjectId = newProjectInfo.getId();
        //拷贝项目信息-团队成员
        copyProjectInfoPerson(projectId, newProjectId);
        //拷贝项目信息-版本记录
        copyProjectInfoVersionRecord(projectId, newProjectId);
        //拷贝项目信息-PDSC
        copyProjectInfoPdsc(projectId, newProjectId);
        //已存在回收站，更改为“废弃”状态
        ProjectInfo oldProjectInfo = getOne(WrapperUtil.toQueryWrapper(ProjectInfo.builder()
                .code(projectInfo.getCode()).version(nextVersion).status(ProjectStatuseEnum.UNDER_PREPARATION.getType())
                .delFlag(CommonConstant.DEL_FLAG_1).build()));
        if (ObjectUtil.isNotNull(oldProjectInfo)) {
            oldProjectInfo.setStatus(ProjectStatuseEnum.ABANDONED.getType());
            updateById(oldProjectInfo);
        }
    }

    /**
     * 通过id查询
     *
     * @param id 主键
     * @return 结果
     */
    @Override
    public ProjectInfoVo queryById(String id) {
        ProjectInfo projectInfo = getById(id);
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        Map<String, String> ownerMap = commonApi.translateDictFromTableByKeys("sys_user", "realname", "id", projectInfo.getOwner(), "master")
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
        Map<String, String> sysOrgCodeMap = commonApi.translateDictFromTableByKeys("sys_depart", "depart_name", "org_code", projectInfo.getSysOrgCode(), "master")
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
        //按钮操作，0:编辑，1:查看
        int btnOperation = ObjectUtil.equals(ProjectStatuseEnum.UNDER_PREPARATION.getType(), projectInfo.getStatus()) ? 0 : 1;
        if (ObjectUtil.notEqual(projectInfo.getOwner(), user.getId())) {
            LambdaQueryWrapper<ProjectInfoPerson> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(ProjectInfoPerson::getProjectId, id);
            List<ProjectInfoPerson> projectInfoPeoples = projectInfoPersonService.list(queryWrapper);
            long coreCount = projectInfoPeoples.stream().filter(v -> ObjectUtil.equals(v.getUserId(), user.getId())
                    && ObjectUtil.equals(PDSCConstant.TEAM_TYPE_CORE, v.getTeamType())).count();
            long extendCount = projectInfoPeoples.stream().filter(v -> ObjectUtil.equals(v.getUserId(), user.getId())
                    && ObjectUtil.equals(PDSCConstant.TEAM_TYPE_EXTEND, v.getTeamType())).count();
            if (coreCount > 0) btnOperation = 0;
            if (extendCount > 0) btnOperation = 1;
        }
        ProjectInfoVo vo = new ProjectInfoVo();
        BeanUtil.copyProperties(projectInfo, vo);
        vo.setOwner_dictText(ownerMap.getOrDefault(projectInfo.getOwner(), StrUtil.EMPTY));
        vo.setSysOrgCode_dictText(sysOrgCodeMap.getOrDefault(projectInfo.getSysOrgCode(), StrUtil.EMPTY));
        vo.setBtnOperation(btnOperation);
        return vo;
    }

    /**
     * 导出excel
     *
     * @param response servlet响应
     * @param req      请求
     */
    @Override
    public void exportXls(HttpServletResponse response, ProjectInfoListReq req) throws Exception {
        ServletOutputStream out = null;
        try (ExcelWriter writer = ExcelUtil.getWriter(true)) {
            LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
            req.setUserId(user.getId());
            List<ProjectInfoListVo> projectInfoListVos = projectInfoMapper.list(req).stream().map(v -> {
                ProjectInfoListVo vo = new ProjectInfoListVo();
                BeanUtil.copyProperties(v, vo);
                return vo;
            }).toList();
            writer.write(buildExportExcelRows(projectInfoListVos), true);
            setExportExcelColumnWidth(projectInfoListVos, writer);
            String fileName = "项目信息" + FileTypeEnum.xlsx.getType();
            response.setHeader("Access-Control-Expose-Headers", "Content-Disposition");
            response.setHeader("Content-disposition", "attachment; filename=" + fileName);
            response.setContentType("application/msexcel");
            out = response.getOutputStream();
            writer.flush(out, true);
        } finally {
            IoUtil.close(out);
        }
    }

    /**
     * 设置excel导出列宽度
     *
     * @param projectInfoListVos 数据
     */
    private void setExportExcelColumnWidth(List<ProjectInfoListVo> projectInfoListVos, ExcelWriter writer) {
        if (CollUtil.isEmpty(projectInfoListVos)) return;
        writer.setColumnWidth(0, 10);
        writer.setColumnWidth(1, 25);
        writer.setColumnWidth(2, 20);
        writer.setColumnWidth(3, 20);
        writer.setColumnWidth(4, 20);
        writer.setColumnWidth(5, 20);
        writer.setColumnWidth(6, 20);
        writer.setColumnWidth(7, 20);
        writer.setColumnWidth(8, 20);
        writer.setColumnWidth(9, 20);
        writer.setColumnWidth(10, 20);
        writer.setColumnWidth(11, 20);
        writer.setColumnWidth(12, 20);
        writer.setColumnWidth(13, 20);
        writer.setColumnWidth(14, 20);
        writer.setColumnWidth(15, 20);
        writer.setColumnWidth(16, 20);
        writer.setColumnWidth(17, 20);
        writer.setColumnWidth(18, 20);
        writer.setColumnWidth(19, 20);
        writer.setColumnWidth(20, 20);
        writer.setColumnWidth(21, 20);
    }

    /**
     * 构建excel导出数据
     *
     * @param projectInfoListVos 数据
     * @return 结果
     */
    private List<Map<String, Object>> buildExportExcelRows(List<ProjectInfoListVo> projectInfoListVos) {
        List<Map<String, Object>> rows = CollUtil.newArrayList();
        int num = 1;
        Map<String, String> projectTypeMap = translateDict("nationrel_pdsc_project_type");
        Map<String, String> ctqGradeMap = translateDict("nationrel_pdsc_ctq_grade");
        Map<String, String> statusMap = translateDict("nationrel_pdsc_status");
        String createBy = projectInfoListVos.stream().map(ProjectInfoListVo::getCreateBy).distinct().collect(Collectors.joining(SymbolConstant.COMMA));
        Map<String, String> usernameMap = commonApi.translateDictFromTableByKeys("sys_user", "realname", "username", createBy, "master")
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
        String owner = projectInfoListVos.stream().map(ProjectInfoListVo::getOwner).distinct().collect(Collectors.joining(SymbolConstant.COMMA));
        Map<String, String> ownerMap = commonApi.translateDictFromTableByKeys("sys_user", "realname", "id", owner, "master")
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
        String sysOrgCode = projectInfoListVos.stream().map(ProjectInfoListVo::getSysOrgCode).distinct().collect(Collectors.joining(SymbolConstant.COMMA));
        Map<String, String> sysOrgCodeMap = commonApi.translateDictFromTableByKeys("sys_depart", "depart_name", "org_code", sysOrgCode, "master")
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
        for (ProjectInfoListVo v : projectInfoListVos) {
            int finalNum = num;
            rows.add(new LinkedHashMap<>() {{
                put("序号", finalNum);
                put("PDSC编号", v.getCode());
                put("PDSC名称", v.getName());
                put("项目名称", v.getProjectName());
                put("产品名称", v.getProductName());
                put("项目类型", projectTypeMap.getOrDefault(v.getProjectType(), StrUtil.EMPTY));
                put("项目阶段", v.getProjectStage());
                put("CTQ级别", ctqGradeMap.getOrDefault(v.getCtqGrade(), StrUtil.EMPTY));
                put("Owner", ownerMap.getOrDefault(v.getOwner(), StrUtil.EMPTY));
                put("创建人", usernameMap.getOrDefault(v.getCreateBy(), StrUtil.EMPTY));
                put("部门", sysOrgCodeMap.getOrDefault(v.getSysOrgCode(), StrUtil.EMPTY));
                put("状态", statusMap.getOrDefault(v.getStatus(), StrUtil.EMPTY));
                put("版本", v.getVersion());
                put("第零关卡时间", DateUtil.formatDate(v.getZeroLevelTime()));
                put("第一关卡时间", DateUtil.formatDate(v.getOneLevelTime()));
                put("第二关卡时间", DateUtil.formatDate(v.getTwoLevelTime()));
                put("第三关卡时间", DateUtil.formatDate(v.getThreeLevelTime()));
                put("第四关卡时间", DateUtil.formatDate(v.getFourLevelTime()));
                put("第五关卡时间", DateUtil.formatDate(v.getFiveLevelTime()));
                put("第六关卡时间", DateUtil.formatDate(v.getSixLevelTime()));
                put("创建日期", DateUtil.formatDate(v.getCreateTime()));
                put("更新日期", DateUtil.formatDate(v.getUpdateTime()));
            }});
            num++;
        }
        return rows;
    }

    /**
     * 翻译字典
     *
     * @param code key值
     * @return 结果
     */
    private Map<String, String> translateDict(String code) {
        return commonApi.queryDictItemsByCode(code)
                .stream().peek(v -> v.setText(MessageUtils.get(v.getText()))).toList()
                .stream().collect(Collectors.toMap(DictModel::getValue, DictModel::getText));
    }

    /**
     * 拷贝项目信息-团队成员
     *
     * @param projectId    项目ID
     * @param newProjectId 新项目ID
     */
    private void copyProjectInfoPerson(String projectId, String newProjectId) {
        List<ProjectInfoPerson> projectInfoPersons = projectInfoPersonService.list(
                WrapperUtil.toQueryWrapper(ProjectInfoPerson.builder().projectId(projectId).build()));
        if (CollectionUtil.isEmpty(projectInfoPersons)) return;
        projectInfoPersons.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setProjectId(newProjectId);
        });
        projectInfoPersonService.saveBatch(projectInfoPersons);
    }

    /**
     * 拷贝项目信息-版本记录
     *
     * @param projectId    项目ID
     * @param newProjectId 新项目ID
     */
    private void copyProjectInfoVersionRecord(String projectId, String newProjectId) {
        List<ProjectInfoVersionRecord> projectInfoVersionRecords = projectInfoVersionRecordService.list(
                WrapperUtil.toQueryWrapper(ProjectInfoVersionRecord.builder().projectId(projectId).build()));
        if (CollectionUtil.isEmpty(projectInfoVersionRecords)) return;
        projectInfoVersionRecords.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setProjectId(newProjectId);
        });
        projectInfoVersionRecordService.saveBatch(projectInfoVersionRecords);
    }

    /**
     * 拷贝项目信息-PDSC
     *
     * @param projectId    项目ID
     * @param newProjectId 新项目ID
     */
    private void copyProjectInfoPdsc(String projectId, String newProjectId) {
        LambdaQueryWrapper<ProjectInfoPdsc> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.select(
                ProjectInfoPdsc::getId,
                ProjectInfoPdsc::getCode,
                ProjectInfoPdsc::getPriority,
                ProjectInfoPdsc::getSortNo,
                ProjectInfoPdsc::getDescription
        );
        queryWrapper.eq(ProjectInfoPdsc::getProjectId, projectId);
        List<ProjectInfoPdsc> projectInfoPdscList = projectInfoPdscService.list(queryWrapper);
        if (CollectionUtil.isEmpty(projectInfoPdscList)) return;
        Map<Integer, String> oldPdscIdMap = projectInfoPdscList.stream().collect(
                Collectors.toMap(ProjectInfoPdsc::getSortNo, ProjectInfoPdsc::getId));
        projectInfoPdscList.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setProjectId(newProjectId);
        });
        projectInfoPdscService.saveBatch(projectInfoPdscList);
        Map<Integer, String> newPdscIdMap = projectInfoPdscList.stream().collect(
                Collectors.toMap(ProjectInfoPdsc::getSortNo, ProjectInfoPdsc::getId));
        Map<String, String> pdscIdMap = new HashMap<>();
        oldPdscIdMap.forEach((k, v) -> pdscIdMap.put(v, newPdscIdMap.get(k)));

        //拷贝PDSC-实际性能
        copyPdscActualPerformance(pdscIdMap);
        //拷贝PDSC-CTQ描述
        copyPdscCtqDescription(pdscIdMap);
        //拷贝PDSC-CTQ属性
        copyPdscCtqProperty(pdscIdMap);
        //拷贝PDSC-缺陷率限制
        copyPdscDefectConfine(pdscIdMap);
        //拷贝PDSC-设计要求
        copyPdscDesignRequire(pdscIdMap);
        //拷贝PDSC-成熟度
        copyPdscMaturity(pdscIdMap);
    }

    /**
     * 拷贝PDSC-实际性能
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscActualPerformance(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscActualPerformance> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscActualPerformance::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscActualPerformance> pdscActualPerformances = pdscActualPerformanceService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscActualPerformances)) return;
        pdscActualPerformances.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscActualPerformanceService.saveBatch(pdscActualPerformances);
    }

    /**
     * 拷贝PDSC-CTQ描述
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscCtqDescription(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscCtqDescription> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscCtqDescription::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscCtqDescription> pdscCtqDescriptions = pdscCtqDescriptionService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscCtqDescriptions)) return;
        pdscCtqDescriptions.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscCtqDescriptionService.saveBatch(pdscCtqDescriptions);
    }

    /**
     * 拷贝PDSC-CTQ属性
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscCtqProperty(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscCtqProperty> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscCtqProperty::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscCtqProperty> pdscCtqPropertyList = pdscCtqPropertyService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscCtqPropertyList)) return;
        pdscCtqPropertyList.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscCtqPropertyService.saveBatch(pdscCtqPropertyList);
    }

    /**
     * 拷贝PDSC-缺陷率限制
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscDefectConfine(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscDefectConfine> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscDefectConfine::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscDefectConfine> pdscDefectConfines = pdscDefectConfineService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscDefectConfines)) return;
        pdscDefectConfines.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscDefectConfineService.saveBatch(pdscDefectConfines);
    }

    /**
     * 拷贝PDSC-设计要求
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscDesignRequire(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscDesignRequire> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscDesignRequire::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscDesignRequire> pdscDesignRequires = pdscDesignRequireService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscDesignRequires)) return;
        pdscDesignRequires.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscDesignRequireService.saveBatch(pdscDesignRequires);
    }

    /**
     * 拷贝PDSC-成熟度
     *
     * @param pdscIdMap PDSC主键map
     */
    private void copyPdscMaturity(Map<String, String> pdscIdMap) {
        LambdaQueryWrapper<PdscMaturity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(PdscMaturity::getPdscId, new ArrayList<>(pdscIdMap.keySet()));
        List<PdscMaturity> pdscMaturityList = pdscMaturityService.list(queryWrapper);
        if (CollectionUtil.isEmpty(pdscMaturityList)) return;
        pdscMaturityList.forEach(v -> {
            v.setId(StrUtil.EMPTY);
            v.setPdscId(pdscIdMap.get(v.getPdscId()));
        });
        pdscMaturityService.saveBatch(pdscMaturityList);
    }
}
